@@ -1,8 +1,7 @@
-leapYear <- function(x) {
-
-  if(!is.numeric(x))
+leapYear <- 
+function(x) {
+  if (!is.numeric(x))
     stop('x must be numeric')
   x <- floor(x)
   x%%4 == 0 & (x%%100 != 0 | x%%400 == 0)
-
 }
\ No newline at end of file
