@@ -1,2 +1,4 @@
-monthNum <- function(y)
-  match(months(y, abbreviate = TRUE), month.abb)
\ No newline at end of file
+monthNum <- 
+function(y) {
+  match(months(y, abbreviate = TRUE), month.abb)
+}
\ No newline at end of file
